@@ -6,7 +6,7 @@ from ..frame.ssl_config import SSLConfigFrame
 
 class _SSLConfigWindow(object):
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u'SSL Config')
         self.dynamic_frame = SSLConfigFrame(parent=self._main_frame)
 
