@@ -22,9 +22,7 @@ def modify(uri,
 
     parts = uri.split(u'/')
     if modifier.passes_filter(parts[HOSTNAME_INDEX]):
-        new_endpoint = (modifier.override
-                        if modifier.override
-                        else modifier.params)
+        new_endpoint = modifier.params
         parts[HOSTNAME_INDEX] = new_endpoint
 
         uri = u'/'.join(parts)
