@@ -4,7 +4,7 @@ import ssl
 import socket
 import logging_helper
 from http.server import HTTPServer
-from threading import currentThread, Thread
+from threading import current_thread, Thread
 from multiprocessing import cpu_count
 from multiprocessing.pool import ThreadPool
 from timingsutil import Timeout
@@ -152,7 +152,7 @@ class WebServer(HTTPServer, object):
 
     def __main_loop(self):
 
-        logging.debug(self.prefix_message(u'main loop ({t})'.format(t=currentThread().name)))
+        logging.debug(self.prefix_message(u'main loop ({t})'.format(t=current_thread().name)))
 
         try:
             self.serve_forever()
